package com.fjhx.purchase.service.purchase.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.common.utils.Assert;
import com.fjhx.purchase.entity.purchase.dto.PurchasePayRecordDetailSelectDto;
import com.fjhx.purchase.entity.purchase.po.Purchase;
import com.fjhx.purchase.entity.purchase.po.PurchasePayRecordDetail;
import com.fjhx.purchase.entity.purchase.vo.PurchasePayRecordDetailVo;
import com.fjhx.purchase.mapper.purchase.PurchasePayRecordDetailMapper;
import com.fjhx.purchase.service.purchase.PurchasePayRecordDetailService;
import com.fjhx.purchase.service.purchase.PurchaseService;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.ruoyi.system.utils.UserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


/**
 * <p>
 * 采购付款记录 服务实现类
 * </p>
 *
 * @author
 * @since 2023-05-23
 */
@Service
public class PurchasePayRecordDetailServiceImpl extends ServiceImpl<PurchasePayRecordDetailMapper, PurchasePayRecordDetail> implements PurchasePayRecordDetailService {

    @Autowired
    private PurchaseService purchaseService;

    @Override
    public Page<PurchasePayRecordDetailVo> getPage(PurchasePayRecordDetailSelectDto dto) {
        IWrapper<PurchasePayRecordDetail> wrapper = getWrapper();
        wrapper.eq(PurchasePayRecordDetail::getPurchaseId, dto.getPurchaseId());
        wrapper.orderByDesc("ppr", PurchasePayRecordDetail::getId);
        Page<PurchasePayRecordDetailVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        UserUtil.assignmentNickName(page.getRecords(), PurchasePayRecordDetailVo::getCreateUser, PurchasePayRecordDetailVo::setPayUserName);
        return page;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void empty(PurchasePayRecordDetailSelectDto dto) {
        Assert.notEmpty(dto.getPurchaseId(), "采购id不能为空");
        //修改付款状态未未付款
        Purchase purchase = purchaseService.getById(dto.getPurchaseId());
        purchase.setPayStatus(0);
        purchaseService.updateById(purchase);
        //清空付款记录
        this.remove(q -> q.eq(PurchasePayRecordDetail::getPurchaseId, dto.getPurchaseId()));
    }

}
